# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import billingo
from billingo.api.document_api import DocumentApi  # noqa: E501
from billingo.rest import ApiException


class TestDocumentApi(unittest.TestCase):
    """DocumentApi unit test stubs"""

    def setUp(self):
        self.api = DocumentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_document(self):
        """Test case for archive_document

        Archive a proforma document.  # noqa: E501
        """
        pass

    def test_cancel_document(self):
        """Test case for cancel_document

        Cancel a document  # noqa: E501
        """
        pass

    def test_create_document(self):
        """Test case for create_document

        Create a document  # noqa: E501
        """
        pass

    def test_create_document_from_draft(self):
        """Test case for create_document_from_draft

        Converts a draft to an invoice.  # noqa: E501
        """
        pass

    def test_create_document_from_proforma(self):
        """Test case for create_document_from_proforma

        Create a document from proforma.  # noqa: E501
        """
        pass

    def test_create_modification_document(self):
        """Test case for create_modification_document

        Create a modification document.  # noqa: E501
        """
        pass

    def test_create_receipt(self):
        """Test case for create_receipt

        Create a receipt  # noqa: E501
        """
        pass

    def test_create_receipt_from_draft(self):
        """Test case for create_receipt_from_draft

        Converts a draft to a receipt.  # noqa: E501
        """
        pass

    def test_delete_document(self):
        """Test case for delete_document

        Delete a draft.  # noqa: E501
        """
        pass

    def test_delete_payment(self):
        """Test case for delete_payment

        Delete all payment history on document  # noqa: E501
        """
        pass

    def test_document_copy(self):
        """Test case for document_copy

        Copy a document  # noqa: E501
        """
        pass

    def test_download_document(self):
        """Test case for download_document

        Download a document in PDF format.  # noqa: E501
        """
        pass

    def test_get_document(self):
        """Test case for get_document

        Retrieve a document  # noqa: E501
        """
        pass

    def test_get_document_by_vendor_id(self):
        """Test case for get_document_by_vendor_id

        Retrieve a document by vendor id  # noqa: E501
        """
        pass

    def test_get_online_szamla_status(self):
        """Test case for get_online_szamla_status

        Retrieve a document Online Számla status  # noqa: E501
        """
        pass

    def test_get_payment(self):
        """Test case for get_payment

        Retrieve a payment histroy  # noqa: E501
        """
        pass

    def test_get_public_url(self):
        """Test case for get_public_url

        Retrieve a document download public url.  # noqa: E501
        """
        pass

    def test_list_document(self):
        """Test case for list_document

        List all documents  # noqa: E501
        """
        pass

    def test_pos_print(self):
        """Test case for pos_print

        Returns a printable POS PDF  # noqa: E501
        """
        pass

    def test_send_document(self):
        """Test case for send_document

        Send invoice to given email adresses.  # noqa: E501
        """
        pass

    def test_update_payment(self):
        """Test case for update_payment

        Update payment history  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
