# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import billingo
from billingo.api.product_api import ProductApi  # noqa: E501
from billingo.rest import ApiException


class TestProductApi(unittest.TestCase):
    """ProductApi unit test stubs"""

    def setUp(self):
        self.api = ProductApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_product(self):
        """Test case for create_product

        Create a product  # noqa: E501
        """
        pass

    def test_delete_product(self):
        """Test case for delete_product

        Delete a product  # noqa: E501
        """
        pass

    def test_get_product(self):
        """Test case for get_product

        Retrieve a product  # noqa: E501
        """
        pass

    def test_list_product(self):
        """Test case for list_product

        List all product  # noqa: E501
        """
        pass

    def test_update_product(self):
        """Test case for update_product

        Update a product  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
