# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import billingo
from billingo.api.spending_api import SpendingApi  # noqa: E501
from billingo.rest import ApiException


class TestSpendingApi(unittest.TestCase):
    """SpendingApi unit test stubs"""

    def setUp(self):
        self.api = SpendingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_spending_delete(self):
        """Test case for spending_delete

        Deletes a spending.  # noqa: E501
        """
        pass

    def test_spending_list(self):
        """Test case for spending_list

        Lists all spending  # noqa: E501
        """
        pass

    def test_spending_save(self):
        """Test case for spending_save

        Creates a new spending.  # noqa: E501
        """
        pass

    def test_spending_show(self):
        """Test case for spending_show

        Retrieves one specific spending.  # noqa: E501
        """
        pass

    def test_spending_update(self):
        """Test case for spending_update

        Updates a spending item.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
